/**
 * EasyBeans
 * Copyright (C) 2007-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EasyBeansCXFListener.java 2545 2008-02-29 13:48:00Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.cxf;

import java.util.List;

import org.ow2.easybeans.server.ServerConfig;
import org.ow2.easybeans.server.war.EasyBeansContextListener;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Listener class which is notified of lifecycle events. It allows to start
 * EasyBeans at startup and stop it at the end.
 * @author Florent Benoit
 */
public class EasyBeansCXFListener extends EasyBeansContextListener {

    /**
     * Resource filename of CXF exported libs.
     */
    private static final String CXF_EXPORTED_LIBRARIES = "cxf-exported-libraries.lst";

    /**
     * Logger.
     */
    private static Log logger = LogFactory.getLog(EasyBeansCXFListener.class);

    @Override
    protected List<String> getExportedLibraries() {
        List<String> list = super.getExportedLibraries();
        list.add(CXF_EXPORTED_LIBRARIES);
        return list;
    }

    /**
     * @return returns the Easybeans ServerConfig object.
     */
    @Override
    protected ServerConfig getServerConfig() {
        ServerConfig config = super.getServerConfig();
        // configure the Callbacks ...
        config.addExtensionFactory(new CXFConfigurationExtension());
        logger.debug("Adding the CXF Factory ''{0}''", CXFConfigurationExtension.class);
        return config;
    }

}
